@@ -24,6 +24,9 @@ from mitosheet.save_utils import read_analysis
 # As the column summary statistics tab does three calls, we defaulted to this max
 MAX_QUEUED_API_CALLS = 3
 
+# NOTE: BE CAREFUL WITH THIS. When in development mode, you can set it
+# so the API calls are handled in the main thread, to make printing easy
+THREADED = True
 
 class API():
     """
@@ -44,6 +47,10 @@ class API():
         self.thread = Thread(target=handle_api_event_thread, args=(self.api_queue, wsc, send), daemon=True)
         self.thread.start()
 
+        # Save some variables for ease
+        self.wsc = wsc
+        self.send = send
+
     def process_new_api_call(self, event):
         """
         We privilege new API calls over old calls, and evict the old ones 
@@ -52,9 +59,13 @@ class API():
         Because we are using a queue, only events that have not been started 
         being processed will get removed.
         """        
-        if self.api_queue.full():
-            self.api_queue.get()
-        self.api_queue.put(event)
+        if THREADED:
+            if self.api_queue.full():
+                self.api_queue.get()
+            self.api_queue.put(event)
+        else:
+            handle_api_event(self.send, event, self.wsc)
+
 
 
 def handle_api_event_thread(queue, wsc, send):
