@@ -59,6 +59,7 @@ STRING_FILTER_CONDITIONS = [
 
 NUMBER_FILTER_CONDITIONS = [
     'number_exactly',
+    'number_not_exactly',
     'greater',
     'greater_than_or_equal',
     'less',
@@ -257,6 +258,8 @@ def get_applied_filter(df, column_header, filter_):
 
         if condition == 'number_exactly':
             return df[column_header] == value
+        elif condition == 'number_not_exactly':
+            return df[column_header] != value
         elif condition == 'greater':
             return df[column_header] > value
         elif condition == 'greater_than_or_equal':
@@ -356,6 +359,7 @@ def get_filter_string(df_name, column_header, filter_):
 
         # NUMBERS
         'number_exactly': '{df_name}[\'{column_header}\'] == {value}',
+        'number_not_exactly': '{df_name}[\'{column_header}\'] != {value}',
         'greater': '{df_name}[\'{column_header}\'] > {value}',
         'greater_than_or_equal': '{df_name}[\'{column_header}\'] >= {value}',
         'less': '{df_name}[\'{column_header}\'] < {value}',
